@@ -2,7 +2,7 @@
 #' @description Converts single or multiple networks into \code{\link{igraph}}'s format for network analysis
 #' 
 #' @param A Adjacency matrix (network matrix) or brain connectivity array
-#' (from \code{\link[NetworkToolbox]{convertConnBrainMat}})
+#' (from \code{convertConnBrainMat})
 #' 
 #' @param neural Defunct.
 #' 
@@ -18,11 +18,22 @@
 #' 
 #' @export
 #Convert matrices to igraph format----
-# Updated 09.08.2021
+# Updated 10.08.2023
 convert2igraph <- function (A, neural = FALSE)
 {
+    # Check for strength of zero
+    original_diagonal <- diag(A)[1]
+    diag(A) <- 0
+    unconnected <- colSums(A) == 0
+    if(any(unconnected)){
+      A <- A[!unconnected, !unconnected]
+    }
+    
+    # Set diagonal back to original
+    diag(A) <- original_diagonal
+    
     net <- igraph::as.igraph(qgraph::qgraph(A,DoNotPlot=TRUE))
-    igraph::vertex_attr(net, "name") <- V(net)$label
+    # igraph::vertex_attr(net, "name") <- igraph::V(net)$label
     return(net)
 }
 #----
\ No newline at end of file
